from json import dumps

from parsys_utilities import as_list
from parsys_utilities.celery_tasks import post_mailgun_email
from parsys_utilities.random import random_id


class Email(object):
    def __init__(self, request, send_emails=True):
        self._send_emails = send_emails
        self._mailgun_api_key = request.registry.settings['mail.mailgun_api_key']
        self._mailgun_domain = request.registry.settings['mail.mailgun_domain']

    def send(self, to, sender, subject, text, html=None, cc=None, bcc=None, reply_to=None, attachments=None,
             recipient_variables=None):
        if not self._send_emails:
            return

        if not to or not subject or not text:
            return

        file_attachments = [('attachment', attachment) for attachment in attachments or []]

        properties = {
            'subject': subject,
            'text': text,
            'from': sender,
            'to': [],
            'cc': [],
            'bcc': [],
        }

        if recipient_variables:
            properties['recipient-variables'] = recipient_variables
        else:
            properties['recipient-variables'] = {}

        # If to is str => transform to list, if to is list, keep the same.
        properties['to'].extend(as_list(to))
        # Force one email per recipient by using recipient variables.
        for recipient in to:
            properties['recipient-variables'][recipient] = properties['recipient-variables'].get(recipient, {})
            properties['recipient-variables'][recipient]['unique-id'] = random_id()

        properties['recipient-variables'] = dumps(properties['recipient-variables'])

        if cc:
            properties['cc'].extend(as_list(cc))

        if bcc:
            properties['bcc'].extend(as_list(bcc))

        if reply_to:
            properties['h:Reply-To'] = reply_to

        if html:
            properties['html'] = html

        post_mailgun_email.apply_async(
            args=[f'https://api.mailgun.net/v3/{self._mailgun_domain}/messages', self._mailgun_api_key],
            kwargs={'files': file_attachments, 'data': properties},
        )
