import re

from parsys_utilities.celery_tasks import post_nexmo_sms


def validate_phone_number(number):
    if not number:
        return

    return bool(re.match(r'^\+[0-9]*$', number))


class SMS(object):
    def __init__(self, request, send_sms=True):
        self._send_sms = send_sms
        self._nexmo_api_key = request.registry.settings.get('sms.nexmo_api_key')
        self._nexmo_api_secret = request.registry.settings.get('sms.nexmo_api_secret')

    def send(self, recipients, senders, text):
        if not self._send_sms:
            return

        if not recipients or not text:
            return

        for recipient in recipients:
            if not validate_phone_number(recipient):
                continue

            if recipient.startswith('+1'):
                sender = senders.get('us')
            else:
                sender = senders.get('default')

            post_nexmo_sms.apply_async(args=[self._nexmo_api_key, self._nexmo_api_secret, sender, recipient, text])
